/*
 *	Linux ethernet bridge
 *
 *	Authors:
 *	Lennert Buytenhek		<buytenh@gnu.org>
 *
 *	$Id: br_private_stp.h,v 1.3 2001/02/05 06:03:47 davem Exp $
 *
 *	This program is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU General Public License
 *	as published by the Free Software Foundation; either version
 *	2 of the License, or (at your option) any later version.
 */

#ifndef _BR_PRIVATE_STP_H
#define _BR_PRIVATE_STP_H

#define BR_BPDU_TYPE_CONFIG 0x00
#define BR_BPDU_TYPE_RST    0x02
#define BR_BPDU_TYPE_TCN    0x80

#define BR_BPDU_ROLE_UNKNOWN    0
#define BR_BPDU_ROLE_ALT_BKP    1
#define BR_BPDU_ROLE_ROOT       2
#define BR_BPDU_ROLE_DESIGNATED 3

struct net_bridge_bpdu
{
	unsigned	is_rst:1;

	unsigned	topology_change:1;
	unsigned	rst_proposal:1;
	unsigned	rst_port_role:2;
	unsigned	rst_learning:1;
	unsigned	rst_forwarding:1;
	unsigned	rst_agreement:1;
	unsigned	topology_change_ack:1;

	bridge_id	root;
	int		root_path_cost;
	bridge_id	bridge_id;
	port_id		port_id;
	int		message_age;
	int		max_age;
	int		hello_time;
	int		forward_delay;
};

/* br_stp.c */
extern int br_is_port_discarding(struct net_bridge_port *);
extern int br_compare_priority_vectors(struct net_bridge_priority_vector *, struct net_bridge_priority_vector *);
extern void br_update_port_info(struct net_bridge_port *);
extern void br_become_root_bridge(struct net_bridge *br);
extern void net_bridge_bpdu_generation(struct net_bridge *);
extern int  br_is_root_bridge(struct net_bridge *br);
extern void br_port_role_selection(struct net_bridge *);
extern void br_port_state_selection(struct net_bridge *);
extern void br_received_config_bpdu(struct net_bridge_port *p, struct net_bridge_bpdu *bpdu);
extern void br_received_tcn_bpdu(struct net_bridge_port *p);
extern void br_tick(unsigned long __data);
extern void br_transmit_config(struct net_bridge_port *p);
extern void br_transmit_tcn(struct net_bridge *br);
extern void br_topology_change_detection(struct net_bridge *br);
extern int  br_all_rerooted(struct net_bridge *br, int ignorePortID);
extern int  br_all_synced(struct net_bridge *br, int ignorePortID);
extern void br_transmit_new_info(struct net_bridge_port *);

/* br_stp_bpdu.c */
extern void br_send_config_bpdu(struct net_bridge_port *, struct net_bridge_bpdu *);
extern void br_send_tcn_bpdu(struct net_bridge_port *);

#endif
